import click
from MOMORING.api.create_project import create_project_dir
from MOMORING.api.create_test import create_test_dir


@click.group()
def cmd1():
    pass


@cmd1.command()
@click.option('-p', '--project', default=None, help='Project name.')
def init(project):
    create_project_dir(project)


@click.group()
def cmd2():
    pass


@cmd2.command()
@click.option('-p', '--path', default=None, help='Path of project directory.')
def test(path):
    create_test_dir(path)


def run():
    cli = click.CommandCollection(sources=[cmd1, cmd2])
    cli()



def get_applications_template(project_name):
    txt = '''\
from momo_PJ_name.utils.nitrogen_utils import get_path, get_cpu_num, get_env_param
import os


def func_on_nitrogen():
    datapath, savedpath, stashpath = get_path()
    
    num_cpu = get_cpu_num()
    
    param = get_env_param('PARAM', default_value='value', type_func=str)

'''
    return txt.replace('momo_PJ_name', project_name)



import os
import shutil
from MOMORING.modules.files.test_template import get_test_template


def create_test_dir(path):
    template = get_test_template()
    test_py_path = os.path.join(path, 'test.py')
    if not os.path.exists(test_py_path):
        with open(test_py_path, 'w') as f:
            f.write(template)

    test_dir = os.path.join(path, 'test')
    if os.path.exists(test_dir):
        shutil.rmtree(test_dir)
    os.mkdir(test_dir)

    for i in ['datapath', 'stashpath', 'savedpath']:
        new_dir_path = os.path.join(test_dir, i)
        if os.path.exists(new_dir_path):
            shutil.rmtree(new_dir_path)
        os.mkdir(new_dir_path)



def get_test_template():
    txt = """\
import os


def prepare():
    # set default path
    os.environ.setdefault('DATAPATH', os.path.join('path', 'datapath'))
    os.environ.setdefault('STASHPATH', os.path.join('path', 'stashpath'))
    os.environ.setdefault('SAVEDPATH', os.path.join('path', 'savedpath'))
    
    # set default env
    json_template = {
        'env': {'None': None},
        'limit': 1
    }
    
    for i in json_template['env'].keys():
        os.environ.setdefault(i, str(json_template['env'][i]))


if __name__ == '__main__':
    prepare()
"""
    return txt



def get_readme_template(project_name):
    txt = '''\
# momo_PJ_name #
!!project description.

## Maintainer ##
!! your email address.

### Nitrogen Job Template ###
```json
{
    "name": "momo_PJ_name",
    "description": "!!project description.",
    "docker_image": "!!docker images",
    "git_url": "!!git url",
    "git_branch": "master",
    "project": "!!project id",
    "datasets": "!!dataset id",
    "command": "!!run command",
    "use_gpu": 0,
    "env": {
        "!!env1": "!!default value",
        "!!env2": "!!default value"
    },
    "resource": {
        "spot": false,
        "cpu": 1,
        "memory": 1,
        "gpu": 0,
        "gpu_model": "standard"
    }
}
```

### Parameters ###
- `!!env`: !!type, default=!!default value. !!explanation

### Input & Output ###
Input:
- `!!file_name`  # !!comments

Output:
```
└── output
    ├── !!file_name_1  # !!comments
    └── !!file_name_2  # !!comments
```
'''
    return txt.replace('momo_PJ_name', project_name)



import os
from MOMORING.modules.create import create_dir, create_python_package, create_file
from MOMORING.modules.files.main_template import get_main_template
from MOMORING.modules.files.nitrogen_utils import nitrogen_utils
from MOMORING.modules.files.git_ignore_template import get_git_ignore_template
from MOMORING.modules.files.readme_template import get_readme_template
from MOMORING.modules.files.applications_template import get_applications_template
from MOMORING.api.create_test import create_test_dir


def create_project_dir(project_name):
    base_proj_name = os.path.basename(project_name)
    outer_dir = project_name.replace(base_proj_name, base_proj_name.lower())
    create_dir(outer_dir)
    os.chdir(outer_dir)

    project_name = os.path.basename(project_name)
    create_python_package(project_name)

    dirs = ['applications', 'api', 'modules', 'utils']
    for i in dirs:
        create_python_package(os.path.join(project_name, i))

    nitrogen_utils_path = os.path.join(project_name,
                                       'utils',
                                       'nitrogen_utils.py')
    create_file(nitrogen_utils_path, txt=nitrogen_utils())
    applications_file_path = os.path.join(project_name,
                                          'applications',
                                          'nitrogen_template.py')
    create_file(applications_file_path, txt=get_applications_template(project_name))
    create_file('main.py', txt=get_main_template())
    create_file('.gitignore', txt=get_git_ignore_template())
    create_file('README.md', txt=get_readme_template(project_name))

    create_test_dir('.')

